@@ -65,18 +65,14 @@ setGeneric("Rfilter", function(x) standardGeneric("Rfilter"))
 setGeneric("flatten", function(x, ...) standardGeneric("flatten"))
 
 ## AnnotationDb
-setGeneric("loadDb", function(file, dbType, dbPackage, ...)
-           standardGeneric("loadDb"))
-
 setGeneric("saveDb", signature="x",
            function(x, file) standardGeneric("saveDb"))
 
-setGeneric("dbConn", function(x) standardGeneric("dbConn"))
+## Don't do this.  There is already a dbconn() method.  So use that one.
+##setGeneric("dbConn", function(x) standardGeneric("dbConn"))
 
 setGeneric("packageName", function(x) standardGeneric("packageName"))
 
-setGeneric("species", function(x) standardGeneric("species"))
-
 setGeneric("columns", signature="x",
            function(x) standardGeneric("columns"))
 
@@ -88,4 +84,6 @@ setGeneric("select", signature="x",
 
 
 
+setGeneric("mapIds", signature="x",
+           function(x, keys, column, keytype, ..., multiVals) standardGeneric("mapIds"))
 
