@@ -1,6 +1,24 @@
+## Three helpers for deprecating keytypes
+## One to just list the bum keytypes
+.listDeprecatedKeytypes <- function(){
+   c('CHR','CHRLOC','CHRLOCEND') ## Uncomment after the release
+}
+## Another for keytypes to remove unwanted keytypes
+.filterDeprecatedKeytypes <- function(keytypes){
+    keytypes[!(keytypes %in% .listDeprecatedKeytypes())]
+}
+## And one for keys and select to warn if the user tries to use them
+.checkForDeprecatedKeytype <- function(keytype){
+    if(any(.listDeprecatedKeytypes() %in% keytype )){
+        warning(wmsg(paste0(keytype,
+    " is deprecated. ",
+    "Please use an appropriate TxDb object or package for this kind of data.")))
+    }
+}
+
 ## Need an accessor for getting the central ID for a DB (when appropriate)
 .getCentralID <- function(x){
-  as.character(dbQuery(dbConn(x),
+  as.character(dbQuery(dbconn(x),
                        "SELECT value FROM metadata WHERE name='CENTRALID'"))
 }
 
@@ -31,7 +49,7 @@
 ## ALSO: I will need a way to deduce the org package that goes with each chip
 ## package. hgu95av2ORGPKG will (for example) get you this.  DONE:
 .getOrgPkg <- function(x){
-  pkgname <- sub(".db$","", AnnotationDbi:::packageName(x))
+  pkgname <- sub(".db$","", packageName(x))
   orgPkgName <- eval(parse(text=paste0(pkgname, "ORGPKG")))
   orgPkgName <- paste0(orgPkgName,".db")
   eval(parse(text=orgPkgName))
@@ -39,14 +57,14 @@
 
 ## This gets the exact path to the chip DB.
 .getChipDbFile <- function(x){
-  pkgname <- sub(".db$","", AnnotationDbi:::packageName(x))
+  pkgname <- sub(".db$","", packageName(x))
   eval(call(paste0(pkgname, "_dbfile")))
 }
 
 ## Limitation: I can only have ONE table and ONE field for each list name.
 ## So if we have fields like GO that should pull back multiple things, then we
 ## have to expand those ahead of time.
-.expandCols <- function(cols){
+.expandCols <- function(x, cols){
   ## known expansions for cols:
   if("CHRLOC" %in% cols){ 
     after <- match("CHRLOC", cols)
@@ -60,7 +78,7 @@
     after <- match("GOALL", cols)
     cols <- append(cols, c("EVIDENCEALL","ONTOLOGYALL"),after) 
   }
-  if("ORF" %in% cols){ 
+  if("ORF" %in% cols && species(x)=="Saccharomyces cerevisiae"){
     after <- match("ORF", cols)
     cols <- append(cols, c("SGD"),after) 
   }  
@@ -276,7 +294,7 @@
                                                         "ENSEMBLPROT",
                                                         "ENSEMBLTRANS",
                                                         "UNIPROT") )]
-    .defTables <- c(.defTables, list("ALIAS2ORF" = c("alias","alias_symbol") ))
+    .defTables <- c(.defTables, list("ALIAS" = c("alias","alias_symbol") ))
   }
   if(species=="Pan troglodytes"){
     .defTables <- .defTables[!(names(.defTables) %in% c("ALIAS",
@@ -463,7 +481,7 @@
   chipDb <- .getChipDbFile(y)
   chipSQL <- paste0("ATTACH '",chipDb,"' AS c")
   #message(chipSQL)
-  dbQuery(dbConn(x), chipSQL)
+  dbQuery(dbconn(x), chipSQL)
 }
 
 
@@ -573,7 +591,7 @@
   ## Take the cols, append the keytype to FRONT
   cols <- unique(c(keytype, cols))
   ## do any necessary col expansion:
-  cols <- unique(.expandCols(cols))
+  cols <- unique(.expandCols(x, cols))
   ## generate the query
   sql <- .generateQuery(x, cols, keytype, keys)
   #message(sql)
@@ -584,10 +602,10 @@
     y <- x ## save for test below
     x <- .getOrgPkg(x) ## then flip to using the org package
   }
-  res <- dbQuery(dbConn(x), sql)
+  res <- dbQuery(dbconn(x), sql)
   ## then cleanup by doing a detach:
   if(exists("y", inherits=FALSE)){ ## I should not have to use inherits=FALSE?
-    dbQuery(dbConn(x), "DETACH DATABASE c")
+    dbQuery(dbconn(x), "DETACH DATABASE c")
   }
   ## then subset to only relevant cols
   res[,(colnames(res) %in% headerTables)]
@@ -670,15 +688,18 @@
         ind = match(keys, tab[[jointype]])
         tab <- tab[ind,,drop=FALSE]
         rownames(tab) <- NULL
-    } else if (!keyTest && rowTest) {
-        txt <- "'select' resulted in 1:many mapping between keys and
-                return rows"
-        warning(paste(strwrap(txt), collapse="\n"))
-    } else if (keyTest && rowTest) { ## User will get data "as is"
-        txt <- "'select' and duplicate query keys resulted in 1:many
-                mapping between keys and return rows"
-        warning(paste(strwrap(txt), collapse="\n"))
     }
+    ## We no longer aim to warn about these.  
+    ## Relevant manual pages may need to be more emphatic.
+#     else if (!keyTest && rowTest) {
+#         txt <- "'select' resulted in 1:many mapping between keys and
+#                 return rows"
+#         warning(paste(strwrap(txt), collapse="\n"))
+#     } else if (keyTest && rowTest) { ## User will get data "as is"
+#         txt <- "'select' and duplicate query keys resulted in 1:many
+#                 mapping between keys and return rows"
+#         warning(paste(strwrap(txt), collapse="\n"))
+#     }
     tab
 }
 
@@ -773,7 +794,7 @@
   res <- .extractData(x, cols=cols, keytype=keytype, keys=keys)
   
   ## these are the colnames we need to have gotten back from the DB
-  expectedCols <- .expandCols(oriCols)
+  expectedCols <- .expandCols(x, oriCols)
   oriTabCols <- .getDBLocs(x, expectedCols, value="field")
   
   ## I need to know the jointype...
@@ -871,7 +892,7 @@
     where <- paste("WHERE ",fullKeytype,"in (",strKeys,")" )
     sql <- paste(sql, where)
     ## then call that
-    res <- dbQuery(dbConn(x), sql)    
+    res <- dbQuery(dbconn(x), sql)    
     ## cleanup and re-organize
     .resort(res, keys, jointype=keytype, fields)
 }
@@ -887,7 +908,8 @@
   if(!.isSingleString(keytype)){
       stop("'keytype' must be a a single string")
   }
-  pkts <- keytypes(x)
+  ## deprecated keytypes are still technically 'valid'
+  pkts <- c(keytypes(x), .listDeprecatedKeytypes())
   if(!(keytype %in% pkts)){
       msg <- paste0("Invalid keytype: ",keytype,". Please use the keytypes method to see a listing of valid arguments.")
       stop(msg)
@@ -943,7 +965,7 @@
 
 ## Helper for setting the jointype to an appropriate default
 .chooseJoinType  <- function(x){
-  if(.getCentralID(x) == "ORF"){
+  if(.getCentralID(x) == "ORF" && species(x) == "Saccharomyces cerevisiae"){
     jointype <- "systematic_name"
   }else{
     jointype <- "gene_id"
@@ -1048,7 +1070,7 @@ setMethod("select", "GODb",
       y <- x ## The old switcheroo
       x <- .getOrgPkg(x)  
   }
-  con <- dbConn(x)
+  con <- dbconn(x)
   tables <- .getDataTables(con)
   cols <- unique(unlist(sapply(tables, FUN=dbListFields, con=con)))
   cols <- cols[!cols %in% "_id"]
@@ -1110,7 +1132,7 @@ setMethod("columns", "GODb",
   table <- .getDBLocs(x, keytype)
   field <- .getDBLocs(x, keytype, value="field")
   sql <- paste("SELECT DISTINCT",field,"FROM",table)
-  res <- dbQuery(dbConn(x), sql)
+  res <- dbQuery(dbconn(x), sql)
   t(res)
 }
 
@@ -1129,29 +1151,35 @@ setMethod("columns", "GODb",
     EGgeneTable <- "entrez_genes"
   }
   ## now decide
-  if(class(x) == "OrgDb"){
+  if(class(x) == "OrgDb" && species(x) != "Plasmodium falciparum"){
     res <- switch(EXPR = keytype,
-                  "ENTREZID" = dbQuery(dbConn(x),
+                  "ENTREZID" = dbQuery(dbconn(x),
                     paste("SELECT gene_id FROM", EGgeneTable), 1L),
-                  "TAIR" = dbQuery(dbConn(x),
+                  "TAIR" = dbQuery(dbconn(x),
                     "SELECT gene_id FROM genes", 1L),
-                  "ORF" = dbQuery(dbConn(x),
+                  "ORF" = dbQuery(dbconn(x),
                     "SELECT systematic_name FROM sgd", 1L),
                   "PROBEID" =
                      stop("PROBEID is not supported for Organism packages"),
                   .queryForKeys(x, keytype))
   }
+  if(class(x) == "OrgDb" && species(x) == "Plasmodium falciparum"){
+    res <-  switch(EXPR = keytype,
+                   "ORF" = dbQuery(dbconn(x),
+                     paste("SELECT gene_id FROM", EGgeneTable), 1L),
+                   .queryForKeys(x, keytype))
+  }
   if(class(x) == "ChipDb"){
     res <- switch(EXPR = keytype,
-                  "ENTREZID" = dbQuery(dbConn(x),
+                  "ENTREZID" = dbQuery(dbconn(x),
                     "SELECT gene_id FROM probes", 1L),
-                  "PROBEID" =  dbQuery(dbConn(x),
+                  "PROBEID" =  dbQuery(dbconn(x),
                     "SELECT DISTINCT probe_id FROM probes", 1L),
                   .queryForKeys(x, keytype))
   }
   if(class(x) == "GODb"){
     res <- switch(EXPR = keytype,
-                  "GOID" =  dbQuery(dbConn(x),
+                  "GOID" =  dbQuery(dbconn(x),
                     "SELECT DISTINCT go_id FROM go_term", 1L),
                   .queryForKeys(x, keytype))
   }
@@ -1166,7 +1194,7 @@ setMethod("columns", "GODb",
         x <- .getOrgPkg(x)
         try(.attachDB(x,y), silent=TRUE) ## not a disaster if we fail
     }
-    con <- dbConn(x)
+    con <- dbconn(x)
     tables <- .getDataTables(con)
     if(exists("y")){
         tables <- c("c.probes", tables)
@@ -1187,13 +1215,14 @@ setMethod("columns", "GODb",
         try(.attachDB(x,y), silent=TRUE) ## not a disaster if we fail
     }
     sql <- paste("SELECT",keytype,"FROM",tab)
-    res <- dbQuery(dbConn(x), sql, 1L)
+    res <- dbQuery(dbconn(x), sql, 1L)
     as.character(res[!is.na(res)])
 }
 
 
 ## general keys function
 .keys <- function(x, keytype){
+    .checkForDeprecatedKeytype(keytype)
     .testForValidKeytype(x, keytype)
     schema <- metadata(x)[metadata(x)$name=="DBSCHEMA",]$value
     if(schema=="NOSCHEMA_DB" || schema=="NOCHIPSCHEMA_DB"){
@@ -1267,21 +1296,21 @@ setMethod("keys", "OrgDb",
       if(missing(keytype)){
         keytype <- .chooseCentralOrgPkgSymbol(x)
       }
-      smartKeys(x=x, keytype=keytype, ..., FUN=AnnotationDbi:::.keys)
+      smartKeys(x=x, keytype=keytype, ..., FUN=.keys)
   }
 )
 
 setMethod("keys", "ChipDb",
     function(x, keytype, ...){
       if(missing(keytype)) keytype <- "PROBEID"
-      smartKeys(x=x, keytype=keytype, ..., FUN=AnnotationDbi:::.keys)
+      smartKeys(x=x, keytype=keytype, ..., FUN=.keys)
   }
 )
 
 setMethod("keys", "GODb",
     function(x, keytype, ...){
       if(missing(keytype)) keytype <- "GOID"
-      smartKeys(x=x, keytype=keytype, ..., FUN=AnnotationDbi:::.keys)
+      smartKeys(x=x, keytype=keytype, ..., FUN=.keys)
   }
 )
 
@@ -1358,12 +1387,18 @@ setMethod("keys", "GODb",
 
 setMethod("keytypes", "OrgDb",
     ## function(x) .filterKeytypes(x, baseType="ENTREZID", keytypesBlackList)
-    function(x) .cols(x, baseType="ENTREZID")
+    function(x){ 
+        kts <- .cols(x, baseType="ENTREZID")
+        .filterDeprecatedKeytypes(kts)
+    }
 )
 
 setMethod("keytypes", "ChipDb",
     ## function(x) .filterKeytypes(x, baseType="PROBEID", keytypesBlackList) 
-    function(x) .cols(x, baseType="ENTREZID")
+    function(x){ 
+        kts <- .cols(x, baseType="ENTREZID")
+        .filterDeprecatedKeytypes(kts)
+    }          
 )
 
 setMethod("keytypes", "GODb",
@@ -1392,7 +1427,7 @@ setMethod("keytypes", "GODb",
 ## library(org.Hs.eg.db)
 ## ls(2)
 
-## con = AnnotationDbi:::dbConn(org.Hs.eg.db)
+## con = AnnotationDbi:::dbconn(org.Hs.eg.db)
 ## keys = head(keys(org.Hs.egCHR))
 
 
@@ -1554,7 +1589,7 @@ setMethod("keytypes", "GODb",
 ## that are actually not available as a bimap (reactome) and 4) I would really
 ## like to be able to transparently pull data from another resource and just
 ## have it appear to be in one place.  Sort of like we currently do for
-## microRNAs with TranscriptDbs
+## microRNAs with TxDbs
 
 
 ## Really radical thoughts:
@@ -1599,16 +1634,6 @@ setMethod("keytypes", "GODb",
 
 
 
-
-
-
-
-
-
-
-
-
-
 ## fieldNames <- c("gene_id","accession","accession")
 ## expectedCols <- c("ENTREZID","ACCNUM","REFSEQ")
 ## type <- 
@@ -1620,3 +1645,92 @@ setMethod("keytypes", "GODb",
 ## select(org.Hs.eg.db,sym,"PFAM",keytype="ALIAS");
 
 ## Problem: our code that filters rows needs to drop the keytype column before filtering NAs
+
+
+
+
+
+#######################################################################
+## Some testing of my deprecation:
+## library(org.Hs.eg.db);  k = head(keys(org.Hs.eg.db, 'ENTREZID')); k; 
+## head(keys(org.Hs.eg.db, 'CHR'));
+## select(org.Hs.eg.db, k, 'SYMBOL', 'ENTREZID');
+## head(select(org.Hs.eg.db, k[1], 'SYMBOL', 'CHR'));
+
+
+
+
+
+
+
+
+
+
+
+## new method for mapping Ids (idea to return a vector)
+## This method will just get all data for one column, one keytype 
+## and one set of keys.  Then it will return either the 1st match for each, 
+## filter out based on a rule OR return a CharacterList
+
+## If the user instead gives a test function for 'multiVals', then it will 
+## be applied to all the resulting matches (should take a vector and return 
+## a result)
+
+## Future ideas:
+## Add 'filter' as a later option for multiVals which just means that the user needs to provide an actual function for the multiVals
+## Add some of the arguments that are now supported by 'keys' to this function.
+
+setMethod("mapIds", "AnnotationDb", function(x, keys, column, keytype, ...,
+            multiVals=c("filter","asNA","first","list","CharacterList")){
+    if(missing(multiVals)) multiVals <- 'first'
+    ## make sure we have reasonable value for multiVals.
+    if(!is.function(multiVals)){
+       match.arg(multiVals)
+    }        
+    ## 1st we have to insist that they NOT use more than one column 
+    ## or keytype
+    if(length(keys)<1){stop(wmsg(
+        "mapIds must have at least one key to match against."))}
+    if(length(column)>1){stop(wmsg("mapIds can only use one column."))}
+    if(length(keytype)>1){stop(wmsg("mapIds can only use one keytype."))}
+    
+    ## next call select()
+    ## TODO: remove the suppressWarnings() call once you get rid of that warning
+    res <- select(x, keys=keys, columns=column, keytype=keytype) 
+    ## then split accordingly (and return sorted by initial keys)
+    res <- split(res[[column]], f=res[[keytype]])[keys]
+
+    ## internal helper to toss out multiply matching things
+    .filtMults <- function(data){
+        idx <- sapply(data, FUN=function(x){
+            if(length(x)==1){x=TRUE}else{x=FALSE}; x })
+        unlist(data[idx])
+    }
+    
+    ## If it's a function then call that
+    if(is.function(multiVals)){
+        res <- sapply(res, FUN=multiVals)
+    }else{
+        res <- switch(multiVals,
+            "list"=res,
+            "filter"=.filtMults(res),
+            "asNA"=sapply(res, FUN=function(x){
+                if(length(x)>1){return(NA)}else{return(x)} }),
+            "CharacterList" = as(res, 'CharacterList'),
+            "first" = sapply(res, FUN=function(x){x[[1]]})
+            )
+    }
+    ## names will already be present
+    res
+})
+
+## TODO: add option to replace multi-matches with NAs or to just remove them.
+## To cleanly handle having 'multiVals' being EITHER a FUN or something else:
+## DO like: if(is.function(multiVals)){}else{match.arg(multiVals)}
+
+
+
+
+
+
+
