@@ -378,21 +378,19 @@ test_select14 <- function(){
 }
 
 test_select15 <- function(){
-  ## Another bug that seems to happen in post-processing...
-  ## the code that resolves duplicated values is going a bit insane...
-  ## (IOW .replaceValues())
-    if(all(.Platform$OS.type == 'windows', .Platform$r_arch == 'i386')){
-        ## Then don't do this test (you will run out of memory)
-    }else{
+    ## Another bug that seems to happen in post-processing...
+    ## the code that resolves duplicated values is going a bit insane...
+    ## (IOW .replaceValues())
+    if(!all(.Platform$OS.type == "windows", .Platform$r_arch == "i386")){
         res <- select(x, keys="100008586", columns(x)) 
         checkTrue(dim(res)[1]>0)
         checkTrue(dim(res)[2]==30)
         checkIdentical(c('ENTREZID','PFAM','IPI','PROSITE','ACCNUM','ALIAS',
-                         'CHR','CHRLOC','CHRLOCCHR','CHRLOCEND','ENZYME',
+                         'CHR', 'CHRLOC','CHRLOCCHR','CHRLOCEND','ENZYME',
                          'MAP','PATH','PMID','REFSEQ','SYMBOL','UNIGENE',
                          'ENSEMBL','ENSEMBLPROT','ENSEMBLTRANS','GENENAME',
-                         'UNIPROT','GO','EVIDENCE','ONTOLOGY','GOALL',
-                         NA,'ONTOLOGYALL','OMIM','UCSCKG'),
+                         'UNIPROT','GO','EVIDENCE','ONTOLOGY','GOALL',NA,
+                         'ONTOLOGYALL','OMIM','UCSCKG'),
                        colnames(res))
     }
 }
@@ -409,3 +407,16 @@ test_select16 <- function(){
 }
 ## TODO: figure out why in this weird corner case there is an extra col for
 ## GOALL called 'NA'...
+
+
+
+test_dbconn_and_dbfile <- function(){
+    resc <- dbconn(org.Hs.eg.db)
+    m <- dbGetQuery(resc, "SELECT * FROM metadata")
+    checkTrue(dim(m)[2] ==2)
+    checkTrue(dim(m)[1] > 10)
+              
+    resf <- dbfile(org.Hs.eg.db)
+    mf <- dbGetQuery(dbConnect(SQLite(), resf), "SELECT * FROM metadata")
+    checkTrue(all(mf == m))
+}
